@@ -159,23 +159,32 @@ class NearestFinder:
 			values = None
 
 		if values is not None:
-			mapping = {x: self._bisect_function(x) for x in values}
+			self._mapping = {x: self._bisect_function(x) for x in values}
 
 			def function(x):
-				return mapping[x]
+				return self._mapping[x]
 		else:
-			mapping = {x: x for x in self._list}
+			self._mapping = {x: x for x in self._list}
 
 			def function(x):
-				if x in mapping:
+				if x in self._mapping:
 					return x
 				else:
 					y = self._bisect_function(x)
-					mapping[x] = y
+					self._mapping[x] = y
 					return y
 
 		self._mapping_function = function
 
+	@property
+	def mapping(self):
+		"""
+		:rtype: dict
+		"""
+		if self._mapping is None:
+			self._create_map_function()
+		return self._mapping.copy()
+
 	def map(self, x):
 		if self._function_type == 'dict':
 			return self._mapping_function(x)
